@@ -1,7 +1,7 @@
 package Data::Random::Tree;
 
 our $DATE = '2016-03-24'; # DATE
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 use 5.010001;
 use strict;
@@ -54,6 +54,12 @@ _
             schema => ['array*', of=>['str*'], min_len=>1],
             req => 1,
             summary => 'Class(es) to use to instantiate node objects',
+            description => <<'_',
+
+Node will be created from a random pick of this list of classes. If you only
+supply one class, then all nodes will be of that class.
+
+_
         },
         code_instantiate_node => {
             schema => 'code*',
@@ -67,8 +73,13 @@ you can customize this by providing a routine to instantiate the node. The code
 
     ($class, $level, $parent)
 
-where `$class` is the class name, `$level` is the current level (0 for root
-node, 1 for its children, and so on), `$parent` is the parent node object.
+where `$class` is the class name (your code can of course create node using any
+class you want), `$level` is the current level (0 for root node, 1 for its
+children, and so on), `$parent` is the parent node object. The code should
+return the node object.
+
+Your code need not set the node's `parent()`, connecting parent and children
+nodes will be performed by this routine.
 
 Example:
 
@@ -146,7 +157,7 @@ Data::Random::Tree - Create random tree
 
 =head1 VERSION
 
-This document describes version 0.01 of Data::Random::Tree (from Perl distribution Data-Random-Tree), released on 2016-03-24.
+This document describes version 0.02 of Data::Random::Tree (from Perl distribution Data-Random-Tree), released on 2016-03-24.
 
 =head1 SYNOPSIS
 
@@ -198,6 +209,9 @@ Arguments ('*' denotes required arguments):
 
 Class(es) to use to instantiate node objects.
 
+Node will be created from a random pick of this list of classes. If you only
+supply one class, then all nodes will be of that class.
+
 =item * B<code_instantiate_node> => I<code>
 
 By default, node object will be created with:
@@ -208,8 +222,13 @@ you can customize this by providing a routine to instantiate the node. The code
 
  ($class, $level, $parent)
 
-where C<$class> is the class name, C<$level> is the current level (0 for root
-node, 1 for its children, and so on), C<$parent> is the parent node object.
+where C<$class> is the class name (your code can of course create node using any
+class you want), C<$level> is the current level (0 for root node, 1 for its
+children, and so on), C<$parent> is the parent node object. The code should
+return the node object.
+
+Your code need not set the node's C<parent()>, connecting parent and children
+nodes will be performed by this routine.
 
 Example:
 
